Index: src/core/SkLazyFnPtr.h |
diff --git a/src/core/SkLazyFnPtr.h b/src/core/SkLazyFnPtr.h |
index 9e9bc1165c946653c96789c6f92cc057c3bf45c2..153578201ae83bba39f6d24e7af5c57072afbc54 100644 |
--- a/src/core/SkLazyFnPtr.h |
+++ b/src/core/SkLazyFnPtr.h |
@@ -42,7 +42,7 @@ public: |
F get() { |
// First, try reading to see if it's already set. |
F fn = (F)sk_atomic_load(&fPtr, sk_memory_order_relaxed); |
- if (fn != NULL) { |
+ if (fn != nullptr) { |
return fn; |
} |
@@ -50,11 +50,11 @@ public: |
fn = Choose(); |
// No particular memory barriers needed; we're not guarding anything but the pointer itself. |
- F prev = (F)sk_atomic_cas(&fPtr, NULL, (void*)fn); |
+ F prev = (F)sk_atomic_cas(&fPtr, nullptr, (void*)fn); |
- // If prev != NULL, someone snuck in and set fPtr concurrently. |
- // If prev == NULL, we did write fn to fPtr. |
- return prev != NULL ? prev : fn; |
+ // If prev != nullptr, someone snuck in and set fPtr concurrently. |
+ // If prev == nullptr, we did write fn to fPtr. |
+ return prev != nullptr ? prev : fn; |
} |
private: |